@@ -11,11 +11,11 @@ Catalyst::Plugin::BootstrapAlert - Replacement for Catalyst::Plugin::StatusMessa
 
 =head1 VERSION
 
-Version 0.30
+Version 0.40
 
 =cut
 
-our $VERSION = '0.30';
+our $VERSION = '0.40';
 
 $VERSION = eval $VERSION;
 
@@ -32,11 +32,11 @@ In MyApp.pm:
 
 In controller where you want to save a message for display on the next page:
 
-   $c->response->redirect( "/?mid=" . $c->set_success_msg("It worked!") );
+   $c->response->redirect( "/?mid=" . $c->set_success_alert("It worked!") );
 
 Or, to save an danger message:
 
-   $c->response->redirect( "/?mid=" . $c->set_danger_msg("Error deleting widget") );
+   $c->response->redirect( "/?mid=" . $c->set_error_msg("Error deleting widget") );
 
 Then, in the controller action that corresponds to the redirect above:
 
@@ -47,13 +47,13 @@ Then, in the controller action that corresponds to the redirect above:
         ...
     }
 
-This would mean simply changing C<$c->load_status_msgs> if using C<Catalyst::Plugin::StatusMessage>.
+This would mean simply changing C<load_status_msgs> if using C<Catalyst::Plugin::StatusMessage>.
 
 And, to display the output (here using L<Template Toolkit|Template>):
 
     ...
     <span class="message">[% success_alert %]</span>
-    <span class="error">[% danger_alert %]</span>
+    <span class="error">[% error_msg %]</span>
     ...
 
 =head1 METHODS
@@ -66,8 +66,8 @@ for display by the viewer.
 
 In general, you will want to include this in an C<auto> or "base" (if
 using Chained dispatch) controller action.  Then, if you have a
-"template wrapper page" that displays "C<success_msg>", "C<info_msg>",
-"C<warning_msg>", and "C<danger_msg>", you can automatically and safely send status messages to
+"template wrapper page" that displays "C<success_alert>", "C<info_alert>",
+"C<warning_alert>", and "C<danger_alert>", you can automatically and safely send status messages to
 any related controller action.
 
 =cut
